@@ -36,10 +36,16 @@ sub said {
     my $self = shift;
     my $msg  = shift;
 
-    my $incoming = $self->incoming_class->new(
-        sender      => $self->user_class->new(name => $msg->{who}),
+    my $sender = $self->user_class->new_with_plugins(
+        name   => $msg->{who},
+        engine => $self->engine,
+    );
+
+    my $incoming = $self->incoming_class->new_with_plugins(
+        sender      => $sender,
         message     => $msg->{body},
         irc_message => $msg,
+        engine      => $self->engine,
     );
     $self->received_message($incoming);
 }
